# -*- coding:utf-8 -*-


"""
Module with dummy functionality that isn't tested, to show a gap
in the code coverage.
"""


class Baz(object):
    """
    A class with many lines that don't get tested
    """
    a = 123
    b = 123
    c = 123
    d = 123
    e = 123
    f = 123
    g = 123
    h = 123
    i = 123
    j = 123
    k = 123
    m = 123
    n = 123
    o = 123
    p = 123
    q = 123
    r = 123
